<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About KeePassX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KeePassX is distributed under the term of the GNU General Public License (GPL) version 2 or (at your option) version 3.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Revision</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Using:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoType</name>
    <message>
        <source>Auto-Type - KeePassX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Couldn&apos;t find an entry that matches the window title:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoTypeAssociationsModel</name>
    <message>
        <source>Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sequence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default sequence</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoTypeSelectDialog</name>
    <message>
        <source>Auto-Type - KeePassX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select entry to Auto-Type:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChangeMasterKeyWidget</name>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Repeat password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Key file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Key files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create Key File...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create Key File : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a key file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you really want to use an empty string as password?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to set key file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to set %1 as the Key file:
%2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DatabaseOpenWidget</name>
    <message>
        <source>Enter master key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Key File:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Key files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select key file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DatabaseRepairWidget</name>
    <message>
        <source>Repair database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Database opened fine. Nothing to do.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Success</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The database has been successfully repaired
You can now save it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to repair the database.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DatabaseSettingsWidget</name>
    <message>
        <source>Database name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Database description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transform rounds:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default username:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use recycle bin:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> MiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Benchmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max. history items:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max. history size:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DatabaseTabWidget</name>
    <message>
        <source>Root</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File not found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open KeePass 1 database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KeePass 1 database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&quot;%1&quot; was modified.
Save changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>locked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The database you are trying to open is locked by another instance of KeePassX.
Do you want to open it anyway? Alternatively the database is opened read-only.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lock database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t lock the database as you are currently editing it.
Please press cancel to finish your changes or discard them.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This database has never been saved.
You can save the database or stop locking it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This database has been modified.
Do you want to save the database before locking it?
Otherwise your changes are lost.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&quot;%1&quot; is in edit mode.
Discard changes and close anyway?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export database to CSV file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CSV file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Writing the CSV file failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The database you are trying to save as is locked by another instance of KeePassX.
Do you want to save it anyway?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DatabaseWidget</name>
    <message>
        <source>Change master key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete entry?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you really want to delete the entry &quot;%1&quot; for good?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete entries?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you really want to delete %1 entries for good?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move entries to recycle bin?</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>Do you really want to move %n entry(s) to the recycle bin?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Delete group?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you really want to delete the group &quot;%1&quot; for good?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move entry to recycle bin?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you really want to move entry &quot;%1&quot; to the recycle bin?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditEntryWidget</name>
    <message>
        <source>Entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Entry history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New attribute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to open file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save attachment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to save the attachment:
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n month(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>1 year</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAdvanced</name>
    <message>
        <source>Additional attributes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Attachments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAutoType</name>
    <message>
        <source>Enable Auto-Type for this entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Inherit default Auto-Type sequence from the group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use custom Auto-Type sequence:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>+</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use default sequence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set custom sequence:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetHistory</name>
    <message>
        <source>Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete all</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetMain</name>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gen.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expires</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Presets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notes:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditGroupWidget</name>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Inherit from parent group (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditGroupWidgetMain</name>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expires</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto-type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use default auto-type sequence of parent group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set default auto-type sequence</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditWidgetIcons</name>
    <message>
        <source>Use default icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use custom icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add custom icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete custom icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t delete icon!</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>Can&apos;t delete icon. Still used by %n item(s).</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t read icon:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditWidgetProperties</name>
    <message>
        <source>Created:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modified:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Accessed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uuid:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EntryAttributesModel</name>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EntryHistoryModel</name>
    <message>
        <source>Last modified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>URL</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EntryModel</name>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>URL</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Group</name>
    <message>
        <source>Recycle Bin</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KeePass1OpenWidget</name>
    <message>
        <source>Import KeePass1 database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KeePass1Reader</name>
    <message>
        <source>Unable to read keyfile.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not a KeePass database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported encryption algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Root</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wrong key or database file is corrupt.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KeePass2Reader</name>
    <message>
        <source>Not a KeePass database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wrong key or database file is corrupt.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selected file is an old KeePass 1 database (.kdb).

You can import it by clicking on Database &gt; &apos;Import KeePass 1 database&apos;.
This is a one-way migration. You won&apos;t be able to open the imported database with the old KeePassX 0.4 version.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Fatal error while testing the cryptographic functions.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KeePassX - Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recent databases</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy attribute to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Groups</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add new entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View/Edit entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add new group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change master key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Database settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import KeePass 1 database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clone entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy username to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy password to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Perform Auto-Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lock databases</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>read-only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export to CSV file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Repair database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save repaired database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordGeneratorWidget</name>
    <message>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Character Types</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upper Case Letters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lower Case Letters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ensure that the password contains characters from every group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Accept</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QCommandLineParser</name>
    <message>
        <source>Displays version information.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Displays this help.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown option &apos;%1&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown options: %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing value after &apos;%1&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unexpected value after &apos;%1&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[options]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Usage: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Options:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arguments:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QSaveFile</name>
    <message>
        <source>Existing file %1 is not writable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Writing canceled by application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Partial write. Partition full?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtIOCompressor</name>
    <message>
        <source>Internal zlib error when compressing: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error writing to underlying device: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error opening underlying device: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error reading data from underlying device: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internal zlib error when decompressing: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtIOCompressor::open</name>
    <message>
        <source>The gzip format not supported in this version of zlib.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internal zlib error: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <source>Find:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Case sensitive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Root group</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsWidget</name>
    <message>
        <source>Application Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Security</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsWidgetGeneral</name>
    <message>
        <source>Remember last databases</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open previous databases on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically save on exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically save after every change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Minimize when copying to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use group icon on entry creation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Global Auto-Type shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use entry title to match windows for global auto-type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show a system tray icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide window to system tray when minimized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember last key files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsWidgetSecurity</name>
    <message>
        <source>Clear clipboard after</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lock databases after inactivity of</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show passwords in cleartext by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always ask before performing auto-type</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UnlockDatabaseWidget</name>
    <message>
        <source>Unlock database</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WelcomeWidget</name>
    <message>
        <source>Welcome!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>KeePassX - cross-platform password manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>filename of the password database to open (*.kdbx)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>path to a custom config file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>key file of the database</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
